/**
 * ownCloud - Calendar App
 *
 * @author Raghu Nayyar
 * @author Georg Ehrke
 * @copyright 2016 Raghu Nayyar <beingminimal@gmail.com>
 * @copyright 2016 Georg Ehrke <oc.list@georgehrke.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

window.app = angular.module('Calendar', [
	'ngMock',
	'ngRoute'
]);

window.OC = {

    linkToRemote: function (url) {
        'use strict';

        return '/base' + url;
    }

};

escapeHTML = function () {
	'use strict';

	return;
};

dav = {
	Client: function() {
		'use strict';
		return {
			request: function () {

			},
			propFind: function () {

			},
			parseMultiStatus: function () {

			}
		};
	}
};

oc_current_user = 'user';

function t(app, text, vars, count, options) {
	'use strict';

	return text;
}

//TODO - properly mock moment in the future
moment.locale('en');
